#!/usr/bin/perl
#
#  Test program to get grib2 data for SREF members
#   -will used conf file like wrf ingest and processing 
#
use File::stat;     # allows access to object stat->size;
$test=0;
my($EPS,$DTG)=@ARGV;
$ENV{workDir} ="/data/ldad/alps_ingest/SREF";
$ENV{configFile} =$ENV{workDir}."/CONFIG/sref_grib2.cfg";
#
#  1a. check for valid inputs
#
if($#ARGV < 0){ print "Need EPS and DTG exiting: SREF 2009032709 \n";  exit;}
print "ARGS  : $#ARGV\n";
#
# User must set this
# if(length($ENV{workDir}) < 5){ ENV{workDir} ="/nws/s1/rgrumm/dataflow/SREFPARA/"; }
#
#  2. Fix time data
#
$YYYYMMDD=substr($DTG,0,8);
$CYCLE   =substr($DTG,8,2);
print "From $ENV{workDIr} get SREF data data is in $ENV{configFile} $YYYYMMDD $CYCLE\n";
#
# 3. Set mandatory data in the CONFIG FILE
#
my @wrfprep = qw(EFS MODELS MEMBERS FILENAME FTPSITE LOCALGRIBDIR); 
#
# 4. Read in Configuration file and set data we can fix data based on DTG (YYYYMMDD and CYCLE)
#    Values are carried in the %Option hash get rid of # lines next will skip lines beginning with # 
#
    open INFILE =>  $ENV{configFile} or die " BUMMER: Configuration file not found ($ENV{configFile}) - $!. \n";
    while (<INFILE>) {
        next if /^#|^$|^\s+/;
        s/ //g;s/\t//g;s/\n//g;
        my @tarray = split(/=/,$_);
        $tarray[1]=~s/YYYYMMDD/$YYYYMMDD/g;
        $tarray[1]=~s/CYCLE/$CYCLE/g;
        $tarray[1]=~s/WORKDIR/$ENV{workDir}/g;
        print "key $tarray[0]  value:  $tarray[1] \n\n";
        $SREFprep{$tarray[0]} = $tarray[1];
    }
    close INFILE;
#
# 5.  Make sure that all the necessary variables have been assigned values.
#      --->Note that not all parameters listed in the conf file are considered
#
#
    foreach my $parms ( @SREFprep ) { die "\n         ERROR: Missing value for $parms in $filename \n\n" if !exists($WRFprep{"$parms"}); }

#
#   6. Local data paths must be confirmed... checked and made
#
system "mkdir -p $SREFprep{LOCALGRIBDIR}" unless -e "$WRFprep{LOCALGRIBDIR}"; 
if(-e $SREFprep{LOCALGRIBDIR}){ print "We have or now have local $SREFprep{LOCALGRIBDIR}\n"; } 
#
#  7. Check what data we have and what data we need to get
#
@models  = split(",",$SREFprep{MODELS});
@members = split(",",$SREFprep{MEMBERS});
%getFiles =();
print "Base file for $#models is $#members\n";
foreach $model (@models){
    	print "Base file for $model is $baseFile\n";
        $baseFile=$SREFprep{FILENAME};
        $baseFile=~s/MODEL/$model/g;
    	print "Base file for $model is $baseFile\n";
    	foreach $member (@members){
            $file =$baseFile;
            $file =~s/PERT/$member/g;
            $fullFileName=$SREFprep{LOCALGRIBDIR}.$file;
            if(-e $fullFileName){
                 if($test){ print "We have this file $file\n";} 
                  my ($result)  = stat $fullFileName;
                  if($result->size < 1000) { print "delete file $file due to size $size\n"; system "rm $fullFileName"; }
                  }
            else {
               $getFiles{$file}=$file;
    	        if($test){print "We need to get this $getFiles{$file}\n";}
                 }
        } #member/pert loop
     } #model loop
#
#   8. Get the data 
#
unless ($wget) { $wget = `whereis wget`; my @wget = split / / => $wget; $wget = $wget[1];}
print "wget is $wget\n";
#
#  wget -a  log file -N time stamp -t 25 (time out in seconds) -nv -L -O for output url would go after
#   -O $LOCALFILE $url/$file
#
for $file (sort keys %getFiles)
  {
    $outFile=$SREFprep{LOCALGRIBDIR}.$file;
    $wgetCMD=$wget." -nv -t 25 -O ".$outFile." ".$SREFprep{FTPSITE}.$file;
    print "$wgetCMD\n";
    system $wgetCMD;
#    my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$size,$atime,$mtime,$ctime,$blksize,$blocks)  = stat $outFile;
    my ($result)  = stat $outFile;
    if($result->size < 1000) { print "delete file $file due to size $size\n"; system "rm $outFile"; }
  } # For block
#
# Note when using -O program will get the file so 0 size files must be cleaned out
#
